@@ -35,17 +35,13 @@ class PackagesUsedTest(unittest.TestCase):
     raw_json = read_data_file("bazel_packages.json")
     content = json.loads(raw_json)
     found_top_level_license = False
-    found_zlib = False
     for l in content["licenses"]:
       print(l["label"])  # for debugging the test
       if l["label"] == "//:license":
         found_top_level_license = True
       if l["label"] == "//third_party/bazel:license":
         found_top_level_license = True
-      if l["label"] == "//third_party/zlib:license":
-        found_zlib = True
     self.assertTrue(found_top_level_license)
-    self.assertTrue(found_zlib)
 
   def test_found_remote_packages(self):
     if os.getenv("TEST_WORKSPACE") != "bazel":
